A simulated dataset specifically designed to be "sensitive" to the choice of a Minimal Important Difference (MID). The mean change score is deliberately set to be near common MID thresholds, with a small standard deviation, making it perfect for demonstrating MID-based sensitivity analyses.
garden_club_sensitiveA tibble with 200 rows and 3 variables:
An integer representing the unique participant identifier.
A numeric value for the measurement occasion (1 = pre, 2 = post).
A numeric value for the outcome, the score on the fictional Gardener Envy Inventory (GEI).
garden_club for a more standard pre-post dataset.